@@ -3,13 +3,13 @@ use strict;
 use warnings;
 use vars qw/$VERSION/;
 
-$Test::Stream::VERSION = '1.302026';
+$Test::Stream::VERSION = '1.302027';
 $VERSION = eval $VERSION;
 
 use Carp qw/croak/;
 use Scalar::Util qw/reftype/;
 
-use Test::Stream::Sync;
+use Test::Stream::Sync();
 
 use Test::Stream::Util qw/try pkg_to_file/;
 
@@ -207,7 +207,14 @@ __END__
 
 =head1 NAME
 
-Test::Stream - Successor to Test::More and Test::Builder.
+Test::Stream - **DEPRECATED** See Test2-Suite instead
+
+=head1 DEPRECATED
+
+B<This distribution is deprecated> in favor of L<Test2>, L<Test2::Suite>, and
+L<Test2::Workflow>.
+
+See L<Test::Stream::Manual::ToTest2> for a conversion guide.
 
 =head1 ***READ THIS FIRST***
 
@@ -255,6 +262,9 @@ module is responsible for loading bundles and plugins for the tools you want.
 By default you are required to specify at least 1 plugin or bundle to load. You
 can subclass Test::Stream to have your own default plugins or bundles.
 
+B<Bundles and plugins can be used directly>, it is not necessary to use
+L<Test::Stream> to load them.
+
 =head1 SYNOPSIS
 
     use Test::Stream -Classic;
@@ -264,6 +274,15 @@ can subclass Test::Stream to have your own default plugins or bundles.
 
     done_testing;
 
+The '-' above means load the specified bundle, this is the same as:
+
+    use Test::Stream::Bundle::Classic;
+
+    ok(1, "This is a pass");
+    ok(0, "This is a fail");
+
+    done_testing;
+
 =head2 SUBCLASS
 
     package My::Loader;
@@ -272,6 +291,8 @@ can subclass Test::Stream to have your own default plugins or bundles.
 
     use parent 'Test::Stream';
 
+    # The 'default' sub just returns a list of import arguments to use byu
+    # default.
     sub default {
         return qw{
             -Bundle1
@@ -597,6 +618,6 @@ Copyright 2015 Chad Granum E<lt>exodist7@gmail.comE<gt>.
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
-See F<http://www.perl.com/perl/misc/Artistic.html>
+See F<http://dev.perl.org/licenses/>
 
 =cut
