@@ -4,8 +4,9 @@ use warnings;
 
 use Carp qw/croak/;
 
-use Test::Stream::Exporter;
+use Test::Stream::Exporter qw/import default_export/;
 
+# Here we are exporting a sub called 'import' that is not our 'import' method.
 default_export import => sub {
     my $class = shift;
     my @caller = caller;
@@ -31,6 +32,13 @@ __END__
 
 Test::Stream::Bundle - Tools to help you write custom bundles.
 
+=head1 DEPRECATED
+
+B<This distribution is deprecated> in favor of L<Test2>, L<Test2::Suite>, and
+L<Test2::Workflow>.
+
+See L<Test::Stream::Manual::ToTest2> for a conversion guide.
+
 =head1 DESCRIPTION
 
 You can reduce your boilerplate by writing your own Test::Stream bundles. A
@@ -44,7 +52,7 @@ bundle is a set of plugins that get loaded all at once to your specifications.
 
     # Gives us an 'import' method that allows this module to be used directly
     # if desired.
-    use Test::Stream::Bundle;
+    use Test::Stream::Bundle qw/import/;
 
     sub plugins {
         return (
@@ -128,6 +136,6 @@ Copyright 2015 Chad Granum E<lt>exodist7@gmail.comE<gt>.
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
-See F<http://www.perl.com/perl/misc/Artistic.html>
+See F<http://dev.perl.org/licenses/>
 
 =cut
