@@ -2,7 +2,7 @@ package Test::Stream::Bundle::Tester;
 use strict;
 use warnings;
 
-use Test::Stream::Bundle;
+use Test::Stream::Bundle qw/import/;
 
 sub plugins {
     return (
@@ -23,6 +23,13 @@ __END__
 
 Test::Stream::Bundle::Tester - Bundle for testing test tools.
 
+=head1 DEPRECATED
+
+B<This distribution is deprecated> in favor of L<Test2>, L<Test2::Suite>, and
+L<Test2::Workflow>.
+
+See L<Test::Stream::Manual::ToTest2> for a conversion guide.
+
 =head1 DESCRIPTION
 
 Plugins that are useful when testing test tools and plugins. This includes
@@ -31,7 +38,7 @@ provided by the Compare plugin.
 
 =head1 SYNOPSIS
 
-    use Test::Stream -V1, -Tester;
+    use Test::Stream Core, -Tester;
 
     is(
         intercept { ok(1, "pass") },
@@ -98,6 +105,6 @@ Copyright 2015 Chad Granum E<lt>exodist7@gmail.comE<gt>.
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
-See F<http://www.perl.com/perl/misc/Artistic.html>
+See F<http://dev.perl.org/licenses/>
 
 =cut
