@@ -3,12 +3,12 @@ use strict;
 use warnings;
 
 use Test::Stream::Util qw/try sub_info/;
-use Test::Stream::Delta;
+use Test::Stream::Delta();
 
 use Carp qw/confess croak/;
 use Scalar::Util qw/blessed/;
 
-use Test::Stream::Exporter;
+use Test::Stream::Exporter qw/import export/;
 export compare => sub {
     my ($got, $check, $convert) = @_;
 
@@ -98,7 +98,6 @@ sub lines {
     return [];
 }
 
-use Test::Stream::Delta;
 sub delta_class { 'Test::Stream::Delta' }
 
 sub deltas { () }
@@ -165,6 +164,13 @@ __END__
 
 Test::Stream::Compare - Tools for comparing data structures.
 
+=head1 DEPRECATED
+
+B<This distribution is deprecated> in favor of L<Test2>, L<Test2::Suite>, and
+L<Test2::Workflow>.
+
+See L<Test::Stream::Manual::ToTest2> for a conversion guide.
+
 =head1 DESCRIPTION
 
 This library is the driving force behind C<is()>. The library is the base class
@@ -178,11 +184,8 @@ for several comparison classes that allow for deep structure comparisons.
     use strict;
     use warnings;
 
-    use Test::Stream::Compare;
-    use Test::Stream::HashBase(
-        base => 'Test::Stream::Compare',
-        accessors => [qw/stuff/],
-    );
+    use base 'Test::Stream::Compare';
+    use Test::Stream::HashBase accessors => [qw/stuff/];
 
     sub name { 'STUFF' }
 
@@ -197,7 +200,7 @@ for several comparison classes that allow for deep structure comparisons.
         my $params = @_;
 
         # Always check if $got even exists, this will be false if no value at
-        # all was recieved. (as opposed to a $got of 'undef' or '0' which are
+        # all was received. (as opposed to a $got of 'undef' or '0' which are
         # valid meaning this field will be true).
         return 0 unless $params{exists};
 
@@ -293,7 +296,7 @@ structure.
 
 =item $op = $check->operator($got)
 
-Returns the operator that was used to compare the check with the recieved data
+Returns the operator that was used to compare the check with the received data
 in C<$got>. If there was no value for got then there will be no arguments,
 undef will only be an argument if undef was seen in C<$got>, this is how you
 can tell the difference between a missing value and an undefined one.
@@ -348,6 +351,6 @@ Copyright 2015 Chad Granum E<lt>exodist7@gmail.comE<gt>.
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
-See F<http://www.perl.com/perl/misc/Artistic.html>
+See F<http://dev.perl.org/licenses/>
 
 =cut
