@@ -2,11 +2,8 @@ package Test::Stream::Compare::Array;
 use strict;
 use warnings;
 
-use Test::Stream::Compare;
-use Test::Stream::HashBase(
-    base => 'Test::Stream::Compare',
-    accessors => [qw/inref ending items order/],
-);
+use base 'Test::Stream::Compare';
+use Test::Stream::HashBase accessors => [qw/inref ending items order/];
 
 use Carp qw/croak confess/;
 use Scalar::Util qw/reftype looks_like_number/;
@@ -166,17 +163,12 @@ __END__
 
 Test::Stream::Compare::Array - Internal representation of an array comparison.
 
-=head1 EXPERIMENTAL CODE WARNING
+=head1 DEPRECATED
 
-B<This is an experimental release!> Test-Stream, and all its components are
-still in an experimental phase. This dist has been released to cpan in order to
-allow testers and early adopters the chance to write experimental new tools
-with it, or to add experimental support for it into old tools.
+B<This distribution is deprecated> in favor of L<Test2>, L<Test2::Suite>, and
+L<Test2::Workflow>.
 
-B<PLEASE DO NOT COMPLETELY CONVERT OLD TOOLS YET>. This experimental release is
-very likely to see a lot of code churn. API's may break at any time.
-Test-Stream should NOT be depended on by any toolchain level tools until the
-experimental phase is over.
+See L<Test::Stream::Manual::ToTest2> for a conversion guide.
 
 =head1 DESCRIPTION
 
@@ -197,7 +189,7 @@ reference to that array.
 
 Set this to true if you would like to fail when the array being validated has
 more items than the check. That is if you check indexes 0-3, but the array
-recieved has values for indexes 0-4, it will fail and list that last item in
+received has values for indexes 0-4, it will fail and list that last item in
 the array as unexpected. If this is false then it is assumed you do not care
 about extra items.
 
@@ -242,7 +234,7 @@ index after the last is used.
 
 =item $arr->add_filter(sub { ... })
 
-Add a filter sub. The filter recieves all remaining values of the array being
+Add a filter sub. The filter receives all remaining values of the array being
 checked, and should return the values that should still be checked. The filter
 will be run between the last item added and the next item added.
 
@@ -281,6 +273,6 @@ Copyright 2015 Chad Granum E<lt>exodist7@gmail.comE<gt>.
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
-See F<http://www.perl.com/perl/misc/Artistic.html>
+See F<http://dev.perl.org/licenses/>
 
 =cut
