@@ -2,10 +2,8 @@ package Test::Stream::Compare::EventMeta;
 use strict;
 use warnings;
 
-use Test::Stream::Compare::Meta;
-use Test::Stream::HashBase(
-    base => 'Test::Stream::Compare::Meta',
-);
+use base 'Test::Stream::Compare::Meta';
+use Test::Stream::HashBase;
 
 sub get_prop_file    { $_[1]->debug->file }
 sub get_prop_line    { $_[1]->debug->line }
@@ -29,17 +27,12 @@ __END__
 
 Test::Stream::Compare::EventMeta - Meta class for events in deep comparisons
 
-=head1 EXPERIMENTAL CODE WARNING
+=head1 DEPRECATED
 
-B<This is an experimental release!> Test-Stream, and all its components are
-still in an experimental phase. This dist has been released to cpan in order to
-allow testers and early adopters the chance to write experimental new tools
-with it, or to add experimental support for it into old tools.
+B<This distribution is deprecated> in favor of L<Test2>, L<Test2::Suite>, and
+L<Test2::Workflow>.
 
-B<PLEASE DO NOT COMPLETELY CONVERT OLD TOOLS YET>. This experimental release is
-very likely to see a lot of code churn. API's may break at any time.
-Test-Stream should NOT be depended on by any toolchain level tools until the
-experimental phase is over.
+See L<Test::Stream::Manual::ToTest2> for a conversion guide.
 
 =head1 DESCRIPTION
 
@@ -74,6 +67,6 @@ Copyright 2015 Chad Granum E<lt>exodist7@gmail.comE<gt>.
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
-See F<http://www.perl.com/perl/misc/Artistic.html>
+See F<http://dev.perl.org/licenses/>
 
 =cut
