@@ -2,11 +2,8 @@ package Test::Stream::Compare::Pattern;
 use strict;
 use warnings;
 
-use Test::Stream::Compare;
-use Test::Stream::HashBase(
-    base => 'Test::Stream::Compare',
-    accessors => [qw/pattern negate/],
-);
+use base 'Test::Stream::Compare';
+use Test::Stream::HashBase accessors => [qw/pattern negate stringify_got/];
 
 use Carp qw/croak/;
 
@@ -15,6 +12,8 @@ sub init {
 
     croak "'pattern' is a required attribute" unless $self->{+PATTERN};
 
+    $self->{+STRINGIFY_GOT} ||= 0;
+
     $self->SUPER::init();
 }
 
@@ -27,8 +26,8 @@ sub verify {
     my ($got, $exists) = @params{qw/got exists/};
 
     return 0 unless $exists;
-    return 0 if ref $got;
     return 0 unless defined($got);
+    return 0 if ref $got && !$self->stringify_got;
 
     return $got !~ $self->{+PATTERN}
         if $self->{+NEGATE};
@@ -49,17 +48,12 @@ __END__
 Test::Stream::Compare::Pattern - Use a pattern to validate values in a deep
 comparison.
 
-=head1 EXPERIMENTAL CODE WARNING
+=head1 DEPRECATED
 
-B<This is an experimental release!> Test-Stream, and all its components are
-still in an experimental phase. This dist has been released to cpan in order to
-allow testers and early adopters the chance to write experimental new tools
-with it, or to add experimental support for it into old tools.
+B<This distribution is deprecated> in favor of L<Test2>, L<Test2::Suite>, and
+L<Test2::Workflow>.
 
-B<PLEASE DO NOT COMPLETELY CONVERT OLD TOOLS YET>. This experimental release is
-very likely to see a lot of code churn. API's may break at any time.
-Test-Stream should NOT be depended on by any toolchain level tools until the
-experimental phase is over.
+See L<Test::Stream::Manual::ToTest2> for a conversion guide.
 
 =head1 DESCRIPTION
 
@@ -95,6 +89,6 @@ Copyright 2015 Chad Granum E<lt>exodist7@gmail.comE<gt>.
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
-See F<http://www.perl.com/perl/misc/Artistic.html>
+See F<http://dev.perl.org/licenses/>
 
 =cut
