@@ -2,11 +2,8 @@ package Test::Stream::Compare::Scalar;
 use strict;
 use warnings;
 
-use Test::Stream::Compare;
-use Test::Stream::HashBase(
-    base => 'Test::Stream::Compare',
-    accessors => [qw/item/],
-);
+use base 'Test::Stream::Compare';
+use Test::Stream::HashBase accessors => [qw/item/];
 
 use Carp qw/croak confess/;
 use Scalar::Util qw/reftype blessed/;
@@ -66,6 +63,13 @@ __END__
 Test::Stream::Compare::Scalar - Representation of a Scalar Ref in deep
 comparisons
 
+=head1 DEPRECATED
+
+B<This distribution is deprecated> in favor of L<Test2>, L<Test2::Suite>, and
+L<Test2::Workflow>.
+
+See L<Test::Stream::Manual::ToTest2> for a conversion guide.
+
 =head1 DESCRIPTION
 
 This is used in deep comparisons to represent a scalar reference.
@@ -106,6 +110,6 @@ Copyright 2015 Chad Granum E<lt>exodist7@gmail.comE<gt>.
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
-See F<http://www.perl.com/perl/misc/Artistic.html>
+See F<http://dev.perl.org/licenses/>
 
 =cut
