@@ -4,11 +4,8 @@ use warnings;
 
 use Carp qw/confess/;
 
-use Test::Stream::Compare;
-use Test::Stream::HashBase(
-    base => 'Test::Stream::Compare',
-    accessors => [qw/input negate/],
-);
+use base 'Test::Stream::Compare';
+use Test::Stream::HashBase accessors => [qw/input negate/];
 
 sub stringify_got { 1 }
 
@@ -65,6 +62,13 @@ __END__
 
 Test::Stream::Compare::String - Compare 2 values as strings
 
+=head1 DEPRECATED
+
+B<This distribution is deprecated> in favor of L<Test2>, L<Test2::Suite>, and
+L<Test2::Workflow>.
+
+See L<Test::Stream::Manual::ToTest2> for a conversion guide.
+
 =head1 DESCRIPTION
 
 This is used to compare 2 items after they are stringified. You can also check
@@ -100,6 +104,6 @@ Copyright 2015 Chad Granum E<lt>exodist7@gmail.comE<gt>.
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
-See F<http://www.perl.com/perl/misc/Artistic.html>
+See F<http://dev.perl.org/licenses/>
 
 =cut
