@@ -6,11 +6,8 @@ use Scalar::Util qw/looks_like_number/;
 
 use Carp qw/carp/;
 
-use Test::Stream::Compare;
-use Test::Stream::HashBase(
-    base => 'Test::Stream::Compare',
-    accessors => [qw/input/],
-);
+use base 'Test::Stream::Compare';
+use Test::Stream::HashBase accessors => [qw/input/];
 
 sub init {
     my $self = shift;
@@ -108,6 +105,6 @@ Copyright 2015 Chad Granum E<lt>exodist7@gmail.comE<gt>.
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
-See F<http://www.perl.com/perl/misc/Artistic.html>
+See F<http://dev.perl.org/licenses/>
 
 =cut
