@@ -6,8 +6,8 @@ use Scalar::Util qw/weaken/;
 use Carp qw/confess croak longmess/;
 use Test::Stream::Util qw/get_tid try pkg_to_file/;
 
-use Test::Stream::Sync;
-use Test::Stream::DebugInfo;
+use Test::Stream::Sync();
+use Test::Stream::DebugInfo();
 
 # Preload some key event types
 my %LOADED = (
@@ -394,6 +394,13 @@ __END__
 
 Test::Stream::Context - Object to represent a testing context.
 
+=head1 DEPRECATED
+
+B<This distribution is deprecated> in favor of L<Test2>, L<Test2::Suite>, and
+L<Test2::Workflow>.
+
+See L<Test::Stream::Manual::ToTest2> for a conversion guide.
+
 =head1 DESCRIPTION
 
 The context object is the primary interface for authors of testing tools
@@ -906,6 +913,6 @@ Copyright 2015 Chad Granum E<lt>exodist7@gmail.comE<gt>.
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
-See F<http://www.perl.com/perl/misc/Artistic.html>
+See F<http://dev.perl.org/licenses/>
 
 =cut
