@@ -306,6 +306,13 @@ __END__
 Test::Stream::Delta - Representation of differences between nested data
 structures.
 
+=head1 DEPRECATED
+
+B<This distribution is deprecated> in favor of L<Test2>, L<Test2::Suite>, and
+L<Test2::Workflow>.
+
+See L<Test::Stream::Manual::ToTest2> for a conversion guide.
+
 =head1 DESCRIPTION
 
 This is used by L<Test::Stream::Compare>. When data structures are compared a
@@ -380,9 +387,9 @@ C<METHOD>.
 
 =item $delta->set_got($val)
 
-Deltas are produced by comparing a recieved data structure 'got' against a
+Deltas are produced by comparing a received data structure 'got' against a
 check data structure 'check'. The 'got' attribute contains the value that was
-recieved for comparison.
+received for comparison.
 
 =item $check = $delta->chk
 
@@ -392,7 +399,7 @@ recieved for comparison.
 
 =item $delta->set_check($check)
 
-Deltas are produced by comparing a recieved data structure 'got' against a
+Deltas are produced by comparing a received data structure 'got' against a
 check data structure 'check'. The 'check' attribute contains the value that was
 expected in the comparison.
 
@@ -428,7 +435,7 @@ an exception being thrown.
 
 =item $string = $delta->render_got
 
-Renders the string that should be used in a table to represent the recieved
+Renders the string that should be used in a table to represent the received
 value in a comparison.
 
 =item $string = $delta->render_check
@@ -501,6 +508,6 @@ Copyright 2015 Chad Granum E<lt>exodist7@gmail.comE<gt>.
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
-See F<http://www.perl.com/perl/misc/Artistic.html>
+See F<http://dev.perl.org/licenses/>
 
 =cut
