@@ -4,9 +4,8 @@ use warnings;
 
 use Test::Stream::Formatter::TAP qw/OUT_ERR/;
 
-use Test::Stream::Event(
-    accessors => [qw/error/],
-);
+use base 'Test::Stream::Event';
+use Test::Stream::HashBase accessors => [qw/error/];
 
 sub to_tap {
     my $self = shift;
@@ -37,6 +36,13 @@ __END__
 
 Test::Stream::Event::Exception - Exception event
 
+=head1 DEPRECATED
+
+B<This distribution is deprecated> in favor of L<Test2>, L<Test2::Suite>, and
+L<Test2::Workflow>.
+
+See L<Test::Stream::Manual::ToTest2> for a conversion guide.
+
 =head1 DESCRIPTION
 
 An exception event will display to STDERR, and will prevent the overall test
@@ -90,6 +96,6 @@ Copyright 2015 Chad Granum E<lt>exodist7@gmail.comE<gt>.
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
-See F<http://www.perl.com/perl/misc/Artistic.html>
+See F<http://dev.perl.org/licenses/>
 
 =cut
