@@ -2,7 +2,7 @@ package Test::Stream::Event::Waiting;
 use strict;
 use warnings;
 
-use Test::Stream::Event;
+use base 'Test::Stream::Event';
 
 sub global { 1 };
 
@@ -18,6 +18,13 @@ __END__
 
 Test::Stream::Event::Waiting - Tell all procs/threads it is time to be done
 
+=head1 DEPRECATED
+
+B<This distribution is deprecated> in favor of L<Test2>, L<Test2::Suite>, and
+L<Test2::Workflow>.
+
+See L<Test::Stream::Manual::ToTest2> for a conversion guide.
+
 =head1 DESCRIPTION
 
 This event has no data of its own. This event is sent out by the IPC system
@@ -51,6 +58,6 @@ Copyright 2015 Chad Granum E<lt>exodist7@gmail.comE<gt>.
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
-See F<http://www.perl.com/perl/misc/Artistic.html>
+See F<http://dev.perl.org/licenses/>
 
 =cut
