@@ -2,7 +2,7 @@ package Test::Stream::Exporter;
 use strict;
 use warnings;
 
-use Test::Stream::Exporter::Meta;
+use Test::Stream::Exporter::Meta();
 
 use Scalar::Util qw/reftype/;
 
@@ -57,6 +57,7 @@ sub export_to {
     my $exports = $meta->exports;
 
     my @imports;
+    my %exclude;
     if ($args && @$args) {
         my %seen;
         my $all = 0;
@@ -71,6 +72,9 @@ sub export_to {
                 $all++ if $tag eq 'all';
                 $def++ if $tag eq 'default';
             }
+            elsif ($item =~ m/^!(.*)$/) {
+                $exclude{$1}++;
+            }
             else {
                 push @imports => $item;
             }
@@ -102,6 +106,8 @@ sub export_to {
             $name = join '' => $prefix, $infix, $postfix;
         }
 
+        next if $exclude{$export};
+
         no strict 'refs';
         *{"$dest\::$name"} = $ref;
     }
@@ -168,6 +174,13 @@ __END__
 
 Test::Stream::Exporter - Declarative exporter for Test::Stream and friends.
 
+=head1 DEPRECATED
+
+B<This distribution is deprecated> in favor of L<Test2>, L<Test2::Suite>, and
+L<Test2::Workflow>.
+
+See L<Test::Stream::Manual::ToTest2> for a conversion guide.
+
 =head1 DESCRIPTION
 
 Test::Stream::Exporter is an internal implementation of some key features from
@@ -369,6 +382,6 @@ Copyright 2015 Chad Granum E<lt>exodist7@gmail.comE<gt>.
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
-See F<http://www.perl.com/perl/misc/Artistic.html>
+See F<http://dev.perl.org/licenses/>
 
 =cut
