@@ -2,7 +2,7 @@ package Test::Stream::HashBase;
 use strict;
 use warnings;
 
-use Carp qw/confess croak/;
+use Carp qw/confess croak carp/;
 use Scalar::Util qw/blessed reftype/;
 
 $Carp::Internal{(__PACKAGE__)}++;
@@ -21,14 +21,20 @@ sub import {
     $file =~ s/(\.*)$/.eval$1/;
     my $eval = "# line 1 \"$file\"\npackage $into;\n";
 
+    my $isa = do { no strict 'refs'; \@{"$into\::ISA"} };
+
+    if(my @bmetas = map { $META{$_} or () } @$isa) {
+        $eval .= "sub " . uc($_) . "() { '$_' };\n" for map { @{$_} } @bmetas;
+    }
+
     if(my $base = $args{base}) {
+        carp "'base' argument to HashBase is deprecated.";
         my $bmeta = $META{$base} || croak "Base class '$base' is not a HashBase class";
 
-        $eval .= "sub " . uc($_) . "() { '$_' };\n" for @$bmeta;
-
-        no strict 'refs';
-        push @{"$into\::ISA"} => $base
-            unless $into->isa($base);
+        unless ($into->isa($base)) {
+            $eval .= "sub " . uc($_) . "() { '$_' };\n" for @$bmeta;
+            push @$isa => $base;
+        }
     }
 
     {
@@ -93,17 +99,12 @@ __END__
 Test::Stream::HashBase - Base class for classes that use a hashref
 of a hash.
 
-=head1 EXPERIMENTAL CODE WARNING
+=head1 DEPRECATED
 
-B<This is an experimental release!> Test-Stream, and all its components are
-still in an experimental phase. This dist has been released to cpan in order to
-allow testers and early adopters the chance to write experimental new tools
-with it, or to add experimental support for it into old tools.
+B<This distribution is deprecated> in favor of L<Test2>, L<Test2::Suite>, and
+L<Test2::Workflow>.
 
-B<PLEASE DO NOT COMPLETELY CONVERT OLD TOOLS YET>. This experimental release is
-very likely to see a lot of code churn. API's may break at any time.
-Test-Stream should NOT be depended on by any toolchain level tools until the
-experimental phase is over.
+See L<Test::Stream::Manual::ToTest2> for a conversion guide.
 
 =head1 SYNOPSIS
 
@@ -132,8 +133,10 @@ Subclass it
     package My::Subclass;
     use strict;
     use warnings;
-    use Test::Stream::HashBase base => 'My::Class',    # subclass
-                          accessors => ['bat'];
+
+    # Note, you should subclass before loading HashBase.
+    use base 'My::Class';
+    use Test::Stream::HashBase accessors => ['bat'];
 
     sub init {
         my $self = shift;
@@ -190,6 +193,9 @@ This is how you define your accessors. See the ACCESSORS section below.
 
 =item base => $class
 
+B<*** DEPRECATED ***> Just C<use base 'Parent::Class';> before loading
+HashBase.
+
 This is how you subclass a Test::Stream::Hashbase class. This will give you all
 the constants of the parent(s).
 
@@ -335,6 +341,6 @@ Copyright 2015 Chad Granum E<lt>exodist7@gmail.comE<gt>.
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
-See F<http://www.perl.com/perl/misc/Artistic.html>
+See F<http://dev.perl.org/licenses/>
 
 =cut
