@@ -3,7 +3,7 @@ use strict;
 use warnings;
 
 use Carp qw/carp croak/;
-use Test::Stream::State;
+use Test::Stream::State();
 use Test::Stream::Util qw/get_tid/;
 
 use Scalar::Util qw/weaken/;
@@ -15,6 +15,7 @@ use Test::Stream::HashBase(
         no_ending
         _todo _meta parent_todo
         _mungers
+        _filters
         _listeners
         _follow_ups
         _formatter
@@ -65,6 +66,10 @@ sub inherit {
     if (my $ms = $from->{+_MUNGERS}) {
         push @{$self->{+_MUNGERS}} => grep { $_->{inherit} } @$ms;
     }
+
+    if (my $fs = $from->{+_FILTERS}) {
+        push @{$self->{+_FILTERS}} => grep { $_->{inherit} } @$fs;
+    }
 }
 
 sub debug_todo {
@@ -175,6 +180,8 @@ sub munge {
     my $self = shift;
     my ($sub, %params) = @_;
 
+    carp "use of mungers is deprecated, look at filters instead. mungers will be removed in the near future.";
+
     carp "Useless addition of a munger in a child process or thread!"
         if $$ != $self->{+PID} || get_tid() != $self->{+TID};
 
@@ -194,6 +201,29 @@ sub unmunge {
     @{$self->{+_MUNGERS}} = grep { !$subs{$_->{code}} } @{$self->{+_MUNGERS}};
 }
 
+sub filter {
+    my $self = shift;
+    my ($sub, %params) = @_;
+
+    carp "Useless addition of a filter in a child process or thread!"
+        if $$ != $self->{+PID} || get_tid() != $self->{+TID};
+
+    croak "filter only takes coderefs for arguments, got '$sub'"
+        unless ref $sub && ref $sub eq 'CODE';
+
+    push @{$self->{+_FILTERS}} => { %params, code => $sub };
+
+    $sub; # Intentional Return
+}
+
+sub unfilter {
+    my $self = shift;
+    carp "Useless removal of a filter in a child process or thread!"
+        if $$ != $self->{+PID} || get_tid() != $self->{+TID};
+    my %subs = map {$_ => $_} @_;
+    @{$self->{+_FILTERS}} = grep { !$subs{$_->{code}} } @{$self->{+_FILTERS}};
+}
+
 sub follow_up {
     my $self = shift;
     my ($sub) = @_;
@@ -271,6 +301,13 @@ sub process {
         }
     }
 
+    if ($self->{+_FILTERS}) {
+        for (@{$self->{+_FILTERS}}) {
+            $e = $_->{code}->($self, $e);
+            return unless $e;
+        }
+    }
+
     my $state = $self->{+STATE};
     $e->update_state($state);
     my $count = $state->count;
@@ -363,6 +400,13 @@ __END__
 
 Test::Stream::Hub - The conduit through which all events flow.
 
+=head1 DEPRECATED
+
+B<This distribution is deprecated> in favor of L<Test2>, L<Test2::Suite>, and
+L<Test2::Workflow>.
+
+See L<Test::Stream::Manual::ToTest2> for a conversion guide.
+
 =head1 SYNOPSIS
 
     use Test::Stream::Hub;
@@ -385,35 +429,33 @@ event pipeline.
 The C<send()> method is used to issue an event to the hub. This method will
 handle thread/fork sync, mungers, listeners, TAP output, etc.
 
-=head2 ALTERING EVENTS
+=head2 ALTERING OR REMOVING EVENTS
 
-    $hub->munge(sub {
+    $hub->filter(sub {
         my ($hub, $event) = @_;
 
-        ... Modify the event object ...
+        my $action = get_action($event);
 
-        # return is ignored.
+        # No action should be taken
+        return $event if $action eq 'none';
+
+        # You want your filter to remove the event
+        return undef if $action eq 'delete';
+
+        if ($action eq 'do_it') {
+            my $new_event = copy_event($event);
+            ... Change your copy of the event ...
+            return $new_event;
+        }
+
+        die "Should not happen";
     });
 
-By default mungers are not inherited by child hubs, that means if you start a
-subtest, the subtest will not inherit the munger. You can change this behavior
+By default filters are not inherited by child hubs, that means if you start a
+subtest, the subtest will not inherit the filter. You can change this behavior
 with the C<inherit> parameter:
 
-    $hub->munge(sub { ... }, inherit => 1);
-
-=head3 DESTROYING OR REPLACING AN EVENT
-
-C<@_> elements are aliased to the arguments passed into the munger from the
-caller. Because of this you can destroy the event so that nothing ever sees it.
-This will be supported so long as perl supports this behavior. There is a check
-in C<send()> to return if a munger destroys the event.
-
-    $hub->munge(sub {
-        my ($hub, $event) = @_;
-        return unless ...;
-
-        $_[1] = undef;
-    });
+    $hub->filter(sub { ... }, inherit => 1);
 
 =head2 LISTENING FOR EVENTS
 
@@ -560,6 +602,8 @@ objects that implement a C<< $formatter->write($event) >> method.
 
 =item $sub = $hub->munge(sub { ... }, inherit => 1)
 
+B<*** DEPRECATED ***> This will be removed in the near future.
+
 This adds your codeblock as a callback. Every event that hits this hub will be
 given to your munger BEFORE it is sent to the formatter. You can make any
 modifications you want to the event object.
@@ -586,6 +630,8 @@ the C<< inherit => 1 >> parameter to allow a munger to be inherited.
 
 =item $hub->unmunge($sub)
 
+B<*** DEPRECATED ***> This will be removed in the near future.
+
 You can use this to remove a munge callback. You must pass in the coderef
 returned by the C<munge()> method.
 
@@ -719,6 +765,6 @@ Copyright 2015 Chad Granum E<lt>exodist7@gmail.comE<gt>.
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
-See F<http://www.perl.com/perl/misc/Artistic.html>
+See F<http://dev.perl.org/licenses/>
 
 =cut
