@@ -15,6 +15,13 @@ __END__
 Test::Stream::Hub::Interceptor::Terminator - Exception class used by
 Test::Stream::Hub::Interceptor
 
+=head1 DEPRECATED
+
+B<This distribution is deprecated> in favor of L<Test2>, L<Test2::Suite>, and
+L<Test2::Workflow>.
+
+See L<Test::Stream::Manual::ToTest2> for a conversion guide.
+
 =head1 SOURCE
 
 The source code repository for Test::Stream can be found at
@@ -43,6 +50,6 @@ Copyright 2015 Chad Granum E<lt>exodist7@gmail.comE<gt>.
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
-See F<http://www.perl.com/perl/misc/Artistic.html>
+See F<http://dev.perl.org/licenses/>
 
 =cut
