@@ -2,7 +2,7 @@ package Test::Stream::IPC;
 use strict;
 use warnings;
 
-use Config;
+use Config qw/%Config/;
 use Carp qw/confess carp longmess/;
 
 use Test::Stream::HashBase(
@@ -94,6 +94,13 @@ __END__
 
 Test::Stream::IPC - Base class for Test::Stream IPC drivers.
 
+=head1 DEPRECATED
+
+B<This distribution is deprecated> in favor of L<Test2>, L<Test2::Suite>, and
+L<Test2::Workflow>.
+
+See L<Test::Stream::Manual::ToTest2> for a conversion guide.
+
 =head1 SYNOPSIS
 
     package Test::Stream::IPC::MyDriver;
@@ -317,6 +324,6 @@ Copyright 2015 Chad Granum E<lt>exodist7@gmail.comE<gt>.
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
-See F<http://www.perl.com/perl/misc/Artistic.html>
+See F<http://dev.perl.org/licenses/>
 
 =cut
