@@ -9,9 +9,9 @@ use Test::Stream::HashBase(
 );
 
 use Scalar::Util qw/blessed/;
-use File::Temp;
-use Storable;
-use File::Spec;
+use File::Temp();
+use Storable();
+use File::Spec();
 
 use Test::Stream::Util qw/try get_tid pkg_to_file/;
 
@@ -287,6 +287,13 @@ __END__
 
 Test::Stream::IPC::Files - Temp dir + Files concurrency model.
 
+=head1 DEPRECATED
+
+B<This distribution is deprecated> in favor of L<Test2>, L<Test2::Suite>, and
+L<Test2::Workflow>.
+
+See L<Test::Stream::Manual::ToTest2> for a conversion guide.
+
 =head1 DESCRIPTION
 
 This is the default, and fallback concurrency model for L<Test::Stream>. This
@@ -338,6 +345,6 @@ Copyright 2015 Chad Granum E<lt>exodist7@gmail.comE<gt>.
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
-See F<http://www.perl.com/perl/misc/Artistic.html>
+See F<http://dev.perl.org/licenses/>
 
 =cut
