@@ -2,7 +2,8 @@ package Test::Stream::Plugin;
 use strict;
 use warnings;
 
-use Test::Stream::Exporter;
+use Test::Stream::Exporter qw/import default_export/;
+# Here we are exporting a sub called 'import' that is not our 'import' method.
 default_export import => sub {
     my $class = shift;
     my @caller = caller;
@@ -22,6 +23,13 @@ __END__
 
 Test::Stream::Plugin - Simple helper for writing plugins
 
+=head1 DEPRECATED
+
+B<This distribution is deprecated> in favor of L<Test2>, L<Test2::Suite>, and
+L<Test2::Workflow>.
+
+See L<Test::Stream::Manual::ToTest2> for a conversion guide.
+
 =head1 DESCRIPTION
 
 This module provides an import method that wraps around a typical
@@ -37,7 +45,7 @@ L<Test::Stream::Exporter> and does not have a custom C<import> method.
     use warnings;
 
     # Provides an 'import' method for us that delegates to load_ts_plugin()
-    use Test::Stream::Plugin;
+    use Test::Stream::Plugin qw/import/;
 
     sub load_ts_plugin {
         my $class = shift;
@@ -80,6 +88,6 @@ Copyright 2015 Chad Granum E<lt>exodist7@gmail.comE<gt>.
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
-See F<http://www.perl.com/perl/misc/Artistic.html>
+See F<http://dev.perl.org/licenses/>
 
 =cut
