@@ -3,7 +3,7 @@ use strict;
 use warnings;
 
 use Test::Stream::Context qw/context/;
-use Test::Stream::Plugin;
+use Test::Stream::Plugin qw/import/;
 
 sub load_ts_plugin {
     my $class = shift;
@@ -27,6 +27,13 @@ __END__
 
 Test::Stream::Plugin::AuthorTest - Only run a test when AUTHOR_TESTING is true.
 
+=head1 DEPRECATED
+
+B<This distribution is deprecated> in favor of L<Test2>, L<Test2::Suite>, and
+L<Test2::Workflow>.
+
+See L<Test::Stream::Manual::ToTest2> for a conversion guide.
+
 =head1 DESCRIPTION
 
 It is common practice to write tests that are only run when the AUTHOR_TESTING,
@@ -35,7 +42,7 @@ trivial) work of creating such a test.
 
 =head1 SYNOPSIS
 
-    use Test::Stream qw/-V1 AuthorTest/;
+    use Test::Stream qw/... AuthorTest/;
 
     ...
 
@@ -47,7 +54,7 @@ Or directly:
 
 You can also specify a variable name to use instead of AUTHOR_TESTING
 
-    use Test::Stream '-V1', AuthorTest => ['THE_VAR'];
+    use Test::Stream AuthorTest => ['THE_VAR'];
 
 or
 
@@ -86,6 +93,6 @@ Copyright 2015 Chad Granum E<lt>exodist7@gmail.comE<gt>.
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
-See F<http://www.perl.com/perl/misc/Artistic.html>
+See F<http://dev.perl.org/licenses/>
 
 =cut
