@@ -4,7 +4,7 @@ use warnings;
 
 use Test::Stream::Capabilities qw/CAN_THREAD/;
 
-use Test::Stream::Plugin;
+use Test::Stream::Plugin qw/import/;
 
 sub load_ts_plugin {
     return if CAN_THREAD;
@@ -29,6 +29,13 @@ __END__
 Test::Stream::Plugin::CanThread - Skip a test file unless the system supports
 threading
 
+=head1 DEPRECATED
+
+B<This distribution is deprecated> in favor of L<Test2>, L<Test2::Suite>, and
+L<Test2::Workflow>.
+
+See L<Test::Stream::Manual::ToTest2> for a conversion guide.
+
 =head1 DESCRIPTION
 
 It is fairly common to write tests that need to use threads. Not all systems
@@ -105,6 +112,6 @@ Copyright 2015 Chad Granum E<lt>exodist7@gmail.comE<gt>.
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
-See F<http://www.perl.com/perl/misc/Artistic.html>
+See F<http://dev.perl.org/licenses/>
 
 =cut
