@@ -2,8 +2,8 @@ package Test::Stream::Plugin::Capabilities;
 use strict;
 use warnings;
 
-use Test::Stream::Capabilities;
-use Test::Stream::Plugin;
+use Test::Stream::Capabilities();
+use Test::Stream::Plugin qw/import/;
 
 use Carp qw/croak/;
 
@@ -36,6 +36,13 @@ __END__
 Test::Stream::Plugin::Capabilities - Import constants to check the capabilities
 of the current system.
 
+=head1 DEPRECATED
+
+B<This distribution is deprecated> in favor of L<Test2>, L<Test2::Suite>, and
+L<Test2::Workflow>.
+
+See L<Test::Stream::Manual::ToTest2> for a conversion guide.
+
 =head1 DESCRIPTION
 
 Sometimes you want to know what capabilities the current system has. Checking
@@ -91,6 +98,6 @@ Copyright 2015 Chad Granum E<lt>exodist7@gmail.comE<gt>.
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
-See F<http://www.perl.com/perl/misc/Artistic.html>
+See F<http://dev.perl.org/licenses/>
 
 =cut
