@@ -5,7 +5,7 @@ use warnings;
 use Test::Stream::Util qw/try/;
 use Carp qw/croak/;
 
-use Test::Stream::Exporter;
+use Test::Stream::Exporter qw/import default_exports/;
 default_exports qw/capture/;
 no Test::Stream::Exporter;
 
@@ -47,6 +47,13 @@ __END__
 
 Test::Stream::Plugin::Capture - Plugin for capturing STDERR and STDOUT.
 
+=head1 DEPRECATED
+
+B<This distribution is deprecated> in favor of L<Test2>, L<Test2::Suite>, and
+L<Test2::Workflow>.
+
+See L<Test::Stream::Manual::ToTest2> for a conversion guide.
+
 =head1 DESCRIPTION
 
 This plugin provides the C<capture { ... }> function which can be used to
@@ -110,6 +117,6 @@ Copyright 2015 Chad Granum E<lt>exodist7@gmail.comE<gt>.
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
-See F<http://www.perl.com/perl/misc/Artistic.html>
+See F<http://dev.perl.org/licenses/>
 
 =cut
