@@ -2,7 +2,7 @@ package Test::Stream::Plugin::Class;
 use strict;
 use warnings;
 
-use Test::Stream::Plugin;
+use Test::Stream::Plugin qw/import/;
 
 use Test::Stream::Util qw/pkg_to_file/;
 
@@ -35,6 +35,13 @@ __END__
 Test::Stream::Plugin::Class - Plugin for loading and aliasing the package you
 are testing.
 
+=head1 DEPRECATED
+
+B<This distribution is deprecated> in favor of L<Test2>, L<Test2::Suite>, and
+L<Test2::Workflow>.
+
+See L<Test::Stream::Manual::ToTest2> for a conversion guide.
+
 =head1 DESCRIPTION
 
 This plugin lets you designate a class as the class you are testing. The plugin
@@ -92,6 +99,6 @@ Copyright 2015 Chad Granum E<lt>exodist7@gmail.comE<gt>.
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
-See F<http://www.perl.com/perl/misc/Artistic.html>
+See F<http://dev.perl.org/licenses/>
 
 =cut
