@@ -2,7 +2,7 @@ package Test::Stream::Plugin::Compare;
 use strict;
 use warnings;
 
-use Test::Stream::Exporter;
+use Test::Stream::Exporter qw/import default_exports exports/;
 default_exports qw/is like/;
 exports qw{
     match mismatch validator
@@ -19,26 +19,26 @@ no Test::Stream::Exporter;
 use Carp qw/croak/;
 use Scalar::Util qw/reftype blessed/;
 
-use Test::Stream::Compare qw/-all/;
+use Test::Stream::Compare qw/compare get_build push_build pop_build build/;
 use Test::Stream::Context qw/context/;
 use Test::Stream::Util qw/rtype/;
 
-use Test::Stream::Compare::Array;
-use Test::Stream::Compare::Custom;
-use Test::Stream::Compare::Event;
-use Test::Stream::Compare::Hash;
-use Test::Stream::Compare::Meta;
-use Test::Stream::Compare::Number;
-use Test::Stream::Compare::Object;
-use Test::Stream::Compare::Pattern;
-use Test::Stream::Compare::Ref;
-use Test::Stream::Compare::Regex;
-use Test::Stream::Compare::Scalar;
-use Test::Stream::Compare::Set;
-use Test::Stream::Compare::String;
-use Test::Stream::Compare::Undef;
-use Test::Stream::Compare::Value;
-use Test::Stream::Compare::Wildcard;
+use Test::Stream::Compare::Array();
+use Test::Stream::Compare::Custom();
+use Test::Stream::Compare::Event();
+use Test::Stream::Compare::Hash();
+use Test::Stream::Compare::Meta();
+use Test::Stream::Compare::Number();
+use Test::Stream::Compare::Object();
+use Test::Stream::Compare::Pattern();
+use Test::Stream::Compare::Ref();
+use Test::Stream::Compare::Regex();
+use Test::Stream::Compare::Scalar();
+use Test::Stream::Compare::Set();
+use Test::Stream::Compare::String();
+use Test::Stream::Compare::Undef();
+use Test::Stream::Compare::Value();
+use Test::Stream::Compare::Wildcard();
 
 sub is($$;$@) {
     my ($got, $exp, $name, @diag) = @_;
@@ -389,8 +389,10 @@ sub convert {
         if $type eq 'HASH';
 
     unless ($strict) {
-        return Test::Stream::Compare::Pattern->new(pattern => $thing)
-            if $type eq 'REGEXP';
+        return Test::Stream::Compare::Pattern->new(
+            pattern       => $thing,
+            stringify_got => 1,
+        ) if $type eq 'REGEXP';
 
         return Test::Stream::Compare::Custom->new(code => $thing)
             if $type eq 'CODE';
@@ -423,6 +425,13 @@ __END__
 
 Test::Stream::Plugin::Compare - Tools for comparing deep data structures.
 
+=head1 DEPRECATED
+
+B<This distribution is deprecated> in favor of L<Test2>, L<Test2::Suite>, and
+L<Test2::Workflow>.
+
+See L<Test::Stream::Manual::ToTest2> for a conversion guide.
+
 =head1 DESCRIPTION
 
 Test::More had C<is_deeply()>. This library is the L<Test::Stream> version.
@@ -551,6 +560,7 @@ sub references will be used as validators. If you provide a regex using
 C<qr/.../>, the regex itself will be used to validate the corresponding value
 in the C<$got> structure. The same is true for coderefs, the value is passed in
 as the first argument (and in C<$_>) and the sub should return a boolean value.
+In this tool regexes will stringify the thing they are checking.
 
     like(
         $some_hash,
@@ -682,11 +692,13 @@ Verify that the value matches the given number using the C<==> operator.
 
 =item $check = match qr/.../
 
-Verify that the value matches the regex pattern.
+Verify that the value matches the regex pattern. This form of pattern check
+will B<NOT> stringify references being checked.
 
 =item $check = mismatch qr/.../
 
-Verify that the value does not match the regex pattern.
+Verify that the value does not match the regex pattern. This form of pattern
+check will B<NOT> stringify references being checked.
 
 =item $check = validator(sub{ ... })
 
@@ -1165,6 +1177,6 @@ Copyright 2015 Chad Granum E<lt>exodist7@gmail.comE<gt>.
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
-See F<http://www.perl.com/perl/misc/Artistic.html>
+See F<http://dev.perl.org/licenses/>
 
 =cut
