@@ -5,7 +5,7 @@ use warnings;
 use Scalar::Util qw/reftype refaddr/;
 use Carp qw/croak confess carp/;
 
-use Test::Stream::Sync;
+use Test::Stream::Sync();
 
 use Test::Stream::Table qw/table/;
 
@@ -18,7 +18,7 @@ use Test::Stream::Util qw{
     render_ref
 };
 
-use Test::Stream::Exporter;
+use Test::Stream::Exporter qw/import default_exports/;
 default_exports qw{
     ok pass fail
     diag note
@@ -185,6 +185,10 @@ sub skip {
     last SKIP;
 }
 
+# For easier grepping
+# sub isa_ok  is defined here
+# sub can_ok  is defined here
+# sub DOES_ok is defined here
 BEGIN {
     for my $op (qw/isa can DOES/) {
         my $sub = sub($;@) {
@@ -197,16 +201,18 @@ BEGIN {
             my @bad;
             for my $item (@items) {
                 my $bool;
-                protect { eval qq/#line $line "$file"\n\$bool = \$thing->$op(\$item); 1/ || die $@ };
+                protect { eval qq/#line $line "$file"\n\$bool = \$thing->$op(\$item); 1/ };
                 next if $bool;
 
                 push @bad => $item;
             }
 
+            my $name = render_ref($thing);
+
             $ctx->ok(
                 !@bad,
-                @items == 1 ? "$thing\->$op('$items[0]')" : "$thing\->$op(...)",
-                [map { "Failed: $thing\->$op('$_')" } @bad],
+                @items == 1 ? "$name\->$op('$items[0]')" : "$name\->$op(...)",
+                [map { "Failed: $name\->$op('$_')" } @bad],
             );
 
             $ctx->release;
@@ -222,16 +228,17 @@ sub ref_ok($;$$) {
     my ($thing, $wanttype, $name) = @_;
     my $ctx = context();
 
+    my $gotname = render_ref($thing);
     my $gottype = reftype($thing);
 
     if (!$gottype) {
-        $ctx->ok(0, $name, ["'$thing' is not a reference"]);
+        $ctx->ok(0, $name, ["'$gotname' is not a reference"]);
         $ctx->release;
         return 0;
     }
 
     if ($wanttype && $gottype ne $wanttype) {
-        $ctx->ok(0, $name, ["'$thing' is not a '$wanttype' reference"]);
+        $ctx->ok(0, $name, ["'$gotname' is not a '$wanttype' reference"]);
         $ctx->release;
         return 0;
     }
@@ -416,6 +423,13 @@ __END__
 Test::Stream::Plugin::Core - Test::Stream implementation of the core testing
 tools.
 
+=head1 DEPRECATED
+
+B<This distribution is deprecated> in favor of L<Test2>, L<Test2::Suite>, and
+L<Test2::Workflow>.
+
+See L<Test::Stream::Manual::ToTest2> for a conversion guide.
+
 =head1 DESCRIPTION
 
 B<This is not a drop-in replacement for Test::More>.
@@ -790,6 +804,6 @@ Copyright 2015 Chad Granum E<lt>exodist7@gmail.comE<gt>.
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
-See F<http://www.perl.com/perl/misc/Artistic.html>
+See F<http://dev.perl.org/licenses/>
 
 =cut
