@@ -2,9 +2,9 @@ package Test::Stream::Plugin::Defer;
 use strict;
 use warnings;
 
-use Test::Stream::DeferredTests;
+use Test::Stream::DeferredTests qw/def do_def/;
 
-use Test::Stream::Exporter;
+use Test::Stream::Exporter qw/import default_exports/;
 default_exports qw/def do_def/;
 no Test::Stream::Exporter;
 
@@ -20,6 +20,13 @@ __END__
 
 Test::Stream::Plugin::Defer - Write tests that get executaed at a later time
 
+=head1 DEPRECATED
+
+B<This distribution is deprecated> in favor of L<Test2>, L<Test2::Suite>, and
+L<Test2::Workflow>.
+
+See L<Test::Stream::Manual::ToTest2> for a conversion guide.
+
 =head1 DESCRIPTION
 
 This is the plugin form of L<Test::Stream::DeferredTests>.
@@ -83,6 +90,6 @@ Copyright 2015 Chad Granum E<lt>exodist7@gmail.comE<gt>.
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
-See F<http://www.perl.com/perl/misc/Artistic.html>
+See F<http://dev.perl.org/licenses/>
 
 =cut
