@@ -5,7 +5,7 @@ use warnings;
 use Test::Stream::Util qw/try/;
 use Carp qw/croak/;
 
-use Test::Stream::Exporter;
+use Test::Stream::Exporter qw/import default_exports/;
 default_exports qw/lives dies/;
 no Test::Stream::Exporter;
 
@@ -36,10 +36,17 @@ __END__
 
 Test::Stream::Plugin::Exception - Simple tools to help test exceptions.
 
+=head1 DEPRECATED
+
+B<This distribution is deprecated> in favor of L<Test2>, L<Test2::Suite>, and
+L<Test2::Workflow>.
+
+See L<Test::Stream::Manual::ToTest2> for a conversion guide.
+
 =head1 SYNOPSIS
 
-    # Loads Exception, we also need 'More', so load that as well.
-    use Test::Stream qw/More Exception/;
+    # Loads Exception, we also need 'Core', so load that as well.
+    use Test::Stream qw/Core Exception/;
 
     ok(lives { ... }, "codeblock did not die");
 
@@ -98,6 +105,6 @@ Copyright 2015 Chad Granum E<lt>exodist7@gmail.comE<gt>.
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
-See F<http://www.perl.com/perl/misc/Artistic.html>
+See F<http://dev.perl.org/licenses/>
 
 =cut
