@@ -2,7 +2,7 @@ package Test::Stream::Plugin::ExitSummary;
 use strict;
 use warnings;
 
-use Test::Stream::Plugin;
+use Test::Stream::Plugin qw/import/;
 
 my $ADDED_HOOK = 0;
 sub load_ts_plugin {
@@ -42,6 +42,13 @@ __END__
 Test::Stream::Plugin::ExitSummary - Add extra diagnostics on failure at the end of the
 test.
 
+=head1 DEPRECATED
+
+B<This distribution is deprecated> in favor of L<Test2>, L<Test2::Suite>, and
+L<Test2::Workflow>.
+
+See L<Test::Stream::Manual::ToTest2> for a conversion guide.
+
 =head1 DESCRIPTION
 
 This will provide some diagnostics after a failed test. These diagnostics can
@@ -81,6 +88,6 @@ Copyright 2015 Chad Granum E<lt>exodist7@gmail.comE<gt>.
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
-See F<http://www.perl.com/perl/misc/Artistic.html>
+See F<http://dev.perl.org/licenses/>
 
 =cut
