@@ -7,10 +7,10 @@ use Scalar::Util qw/blessed/;
 use Test::Stream::Util qw/try/;
 use Test::Stream::Context qw/context/;
 
-use Test::Stream::Hub::Interceptor;
-use Test::Stream::Hub::Interceptor::Terminator;
+use Test::Stream::Hub::Interceptor();
+use Test::Stream::Hub::Interceptor::Terminator();
 
-use Test::Stream::Exporter;
+use Test::Stream::Exporter qw/import default_exports/;
 default_exports qw/intercept/;
 no Test::Stream::Exporter;
 
@@ -71,6 +71,13 @@ __END__
 
 Test::Stream::Plugin::Intercept - Tool for intercepting test events.
 
+=head1 DEPRECATED
+
+B<This distribution is deprecated> in favor of L<Test2>, L<Test2::Suite>, and
+L<Test2::Workflow>.
+
+See L<Test::Stream::Manual::ToTest2> for a conversion guide.
+
 =head1 SYNOPSIS
 
     # Load the Intercept plugin, and others we need
@@ -167,6 +174,6 @@ Copyright 2015 Chad Granum E<lt>exodist7@gmail.comE<gt>.
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
-See F<http://www.perl.com/perl/misc/Artistic.html>
+See F<http://dev.perl.org/licenses/>
 
 =cut
