@@ -2,7 +2,7 @@ package Test::Stream::Plugin::LoadPlugin;
 use strict;
 use warnings;
 
-use Test::Stream::Exporter;
+use Test::Stream::Exporter qw/import default_exports/;
 default_exports qw/load_plugin/;
 no Test::Stream::Exporter;
 
@@ -24,6 +24,13 @@ __END__
 Test::Stream::Plugin::LoadPlugin - Load a plugin with full Test::Stream
 semantics, but at runtime.
 
+=head1 DEPRECATED
+
+B<This distribution is deprecated> in favor of L<Test2>, L<Test2::Suite>, and
+L<Test2::Workflow>.
+
+See L<Test::Stream::Manual::ToTest2> for a conversion guide.
+
 =head1 DESCRIPTION
 
 When testing plugins it can be useful to load them multiple times with
@@ -69,6 +76,6 @@ Copyright 2015 Chad Granum E<lt>exodist7@gmail.comE<gt>.
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
-See F<http://www.perl.com/perl/misc/Artistic.html>
+See F<http://dev.perl.org/licenses/>
 
 =cut
