@@ -2,8 +2,8 @@ package Test::Stream::Plugin::SRand;
 use strict;
 use warnings;
 
-use Test::Stream::Plugin;
-use Test::Stream::Sync;
+use Test::Stream::Plugin qw/import/;
+use Test::Stream::Sync();
 
 use Carp qw/carp/;
 
@@ -77,6 +77,13 @@ sub load_ts_plugin {
 Test::Stream::Plugin::SRand - Control the random seed for more controlled test
 environments.
 
+=head1 DEPRECATED
+
+B<This distribution is deprecated> in favor of L<Test2>, L<Test2::Suite>, and
+L<Test2::Workflow>.
+
+See L<Test::Stream::Manual::ToTest2> for a conversion guide.
+
 =head1 DESCRIPTION
 
 This module gives you control over the random seed used for your unit tests. In
@@ -137,6 +144,6 @@ Copyright 2015 Chad Granum E<lt>exodist7@gmail.comE<gt>.
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
-See F<http://www.perl.com/perl/misc/Artistic.html>
+See F<http://dev.perl.org/licenses/>
 
 =cut
