@@ -2,9 +2,9 @@ package Test::Stream::Plugin::TAP;
 use strict;
 use warnings;
 
-use Test::Stream::Sync;
-use Test::Stream::Formatter::TAP;
-use Test::Stream::Plugin;
+use Test::Stream::Sync();
+use Test::Stream::Formatter::TAP();
+use Test::Stream::Plugin qw/import/;
 
 sub load_ts_plugin {
     return if Test::Stream::Sync->init_done;
@@ -23,6 +23,13 @@ __END__
 
 Test::Stream::Plugin::TAP - Plugin to set TAP as the default output formatter.
 
+=head1 DEPRECATED
+
+B<This distribution is deprecated> in favor of L<Test2>, L<Test2::Suite>, and
+L<Test2::Workflow>.
+
+See L<Test::Stream::Manual::ToTest2> for a conversion guide.
+
 =head1 DESCRIPTION
 
 L<Test::Stream> does not force you to use TAP output the way L<Test::Builder>
@@ -63,6 +70,6 @@ Copyright 2015 Chad Granum E<lt>exodist7@gmail.comE<gt>.
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
-See F<http://www.perl.com/perl/misc/Artistic.html>
+See F<http://dev.perl.org/licenses/>
 
 =cut
