@@ -5,7 +5,7 @@ use warnings;
 use Carp qw/croak/;
 use Test::Stream::Util qw/protect/;
 
-use Test::Stream::Exporter;
+use Test::Stream::Exporter qw/import default_exports/;
 default_exports qw/warning warns no_warnings/;
 no Test::Stream::Exporter;
 
@@ -48,10 +48,17 @@ __END__
 Test::Stream::Plugin::Warnings - Simple tools for testing code that may
 generate warnings.
 
+=head1 DEPRECATED
+
+B<This distribution is deprecated> in favor of L<Test2>, L<Test2::Suite>, and
+L<Test2::Workflow>.
+
+See L<Test::Stream::Manual::ToTest2> for a conversion guide.
+
 =head1 SYNOPSIS
 
-    # Load the Warnings plugin, and More cause we need that as well.
-    use Test::Stream qw/More Warnings/;
+    # Load the Warnings plugin, and Core cause we need that as well.
+    use Test::Stream qw/Core Warnings/;
 
     # Returns undef if there are no warnings.
     ok(!warns { ... }, "Codeblock did not warn");
@@ -142,6 +149,6 @@ Copyright 2015 Chad Granum E<lt>exodist7@gmail.comE<gt>.
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
-See F<http://www.perl.com/perl/misc/Artistic.html>
+See F<http://dev.perl.org/licenses/>
 
 =cut
