@@ -8,8 +8,8 @@ use Scalar::Util qw/reftype blessed/;
 use Test::Stream::Capabilities qw/CAN_FORK/;
 use Test::Stream::Util qw/get_tid USE_THREADS pkg_to_file/;
 
-use Test::Stream::DebugInfo;
-use Test::Stream::Stack;
+use Test::Stream::DebugInfo();
+use Test::Stream::Stack();
 
 # This package is NOT an object. It is global in nature and I don't want people
 # fscking with it. It is small, with only the following variables. These are
@@ -269,17 +269,18 @@ __END__
 Test::Stream::Sync - Primary Synchronization point, this is where global stuff
 lives.
 
-=head1 EXPERIMENTAL CODE WARNING
+=head1 DEPRECATED
 
-B<This is an experimental release!> Test-Stream, and all its components are
-still in an experimental phase. This dist has been released to cpan in order to
-allow testers and early adopters the chance to write experimental new tools
-with it, or to add experimental support for it into old tools.
+B<This distribution is deprecated> in favor of L<Test2>, L<Test2::Suite>, and
+L<Test2::Workflow>.
 
-B<PLEASE DO NOT COMPLETELY CONVERT OLD TOOLS YET>. This experimental release is
-very likely to see a lot of code churn. API's may break at any time.
-Test-Stream should NOT be depended on by any toolchain level tools until the
-experimental phase is over.
+See L<Test::Stream::Manual::ToTest2> for a conversion guide.
+
+=head1 ***INTERNALS NOTE***
+
+B<The internals of this package are subject to change at any time!> The public
+methods provided will not change in backwords incompatible ways, but the
+underlying implementation details might. B<Do not break encapsulation here!>
 
 =head1 DESCRIPTION
 
@@ -423,6 +424,6 @@ Copyright 2015 Chad Granum E<lt>exodist7@gmail.comE<gt>.
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
-See F<http://www.perl.com/perl/misc/Artistic.html>
+See F<http://dev.perl.org/licenses/>
 
 =cut
