@@ -2,14 +2,14 @@ package Test::Stream::Table;
 use strict;
 use warnings;
 
-use Test::Stream::Table::LineBreak;
+use Test::Stream::Table::LineBreak();
 
 use List::Util qw/min max sum/;
 use Scalar::Util qw/blessed/;
 
 use Test::Stream::Util qw/term_size/;
 
-use Test::Stream::Exporter;
+use Test::Stream::Exporter qw/import exports/;
 exports qw/table/;
 no Test::Stream::Exporter;
 
@@ -198,6 +198,13 @@ __END__
 
 Test::Stream::Table - Format a header and rows into a table
 
+=head1 DEPRECATED
+
+B<This distribution is deprecated> in favor of L<Test2>, L<Test2::Suite>, and
+L<Test2::Workflow>.
+
+See L<Test::Stream::Manual::ToTest2> for a conversion guide.
+
 =head1 DESCRIPTION
 
 This is used by some failing tests to provide diagnostics about what has gone
@@ -320,6 +327,6 @@ Copyright 2015 Chad Granum E<lt>exodist7@gmail.comE<gt>.
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
-See F<http://www.perl.com/perl/misc/Artistic.html>
+See F<http://dev.perl.org/licenses/>
 
 =cut
