@@ -5,7 +5,7 @@ use warnings;
 use Test::Stream::Capabilities qw/CAN_THREAD/;
 use Scalar::Util qw/reftype blessed refaddr/;
 use Carp qw/croak/;
-use B;
+use B();
 
 use Test::Stream::Exporter qw/import export_to exports/;
 exports qw{
@@ -301,6 +301,8 @@ sub rtype {
 sub render_ref {
     my ($in) = @_;
 
+    return 'undef' unless defined($in);
+
     my $type = rtype($in);
     return "$in" unless $type;
 
@@ -371,17 +373,12 @@ __END__
 
 Test::Stream::Util - Tools used by Test::Stream and friends.
 
-=head1 EXPERIMENTAL CODE WARNING
+=head1 DEPRECATED
 
-B<This is an experimental release!> Test-Stream, and all its components are
-still in an experimental phase. This dist has been released to cpan in order to
-allow testers and early adopters the chance to write experimental new tools
-with it, or to add experimental support for it into old tools.
+B<This distribution is deprecated> in favor of L<Test2>, L<Test2::Suite>, and
+L<Test2::Workflow>.
 
-B<PLEASE DO NOT COMPLETELY CONVERT OLD TOOLS YET>. This experimental release is
-very likely to see a lot of code churn. API's may break at any time.
-Test-Stream should NOT be depended on by any toolchain level tools until the
-experimental phase is over.
+See L<Test::Stream::Manual::ToTest2> for a conversion guide.
 
 =head1 DESCRIPTION
 
@@ -591,6 +588,6 @@ Copyright 2015 Chad Granum E<lt>exodist7@gmail.comE<gt>.
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
-See F<http://www.perl.com/perl/misc/Artistic.html>
+See F<http://dev.perl.org/licenses/>
 
 =cut
