@@ -5,7 +5,7 @@ use warnings;
 use Carp qw/confess croak/;
 use Scalar::Util qw/blessed/;
 
-use Test::Stream::Workflow::Unit;
+use Test::Stream::Workflow::Unit();
 
 use Test::Stream::HashBase(
     accessors => [qw/unit runner runner_args autorun/],
@@ -104,6 +104,13 @@ __END__
 
 Test::Stream::Workflow::Meta - Meta-data for tests using workflows
 
+=head1 DEPRECATED
+
+B<This distribution is deprecated> in favor of L<Test2>, L<Test2::Suite>, and
+L<Test2::Workflow>.
+
+See L<Test::Stream::Manual::ToTest2> for a conversion guide.
+
 =head1 EXPERIMENTAL CODE WARNING
 
 C<This module is still EXPERIMENTAL>. Test-Stream is now stable, but this
@@ -207,6 +214,6 @@ Copyright 2015 Chad Granum E<lt>exodist7@gmail.comE<gt>.
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
-See F<http://www.perl.com/perl/misc/Artistic.html>
+See F<http://dev.perl.org/licenses/>
 
 =cut
