@@ -4,8 +4,8 @@ use warnings;
 
 use Test::Stream::Util qw/try/;
 
-use Test::Stream::Workflow::Task;
-use Test::Stream::Sync;
+use Test::Stream::Workflow::Task();
+use Test::Stream::Sync();
 
 sub subtests { 1 }
 
@@ -80,6 +80,13 @@ __END__
 
 Test::Stream::Workflow::Runner - Simple runner for workflows.
 
+=head1 DEPRECATED
+
+B<This distribution is deprecated> in favor of L<Test2>, L<Test2::Suite>, and
+L<Test2::Workflow>.
+
+See L<Test::Stream::Manual::ToTest2> for a conversion guide.
+
 =head1 EXPERIMENTAL CODE WARNING
 
 C<This module is still EXPERIMENTAL>. Test-Stream is now stable, but this
@@ -228,6 +235,6 @@ Copyright 2015 Chad Granum E<lt>exodist7@gmail.comE<gt>.
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
-See F<http://www.perl.com/perl/misc/Artistic.html>
+See F<http://dev.perl.org/licenses/>
 
 =cut
