@@ -2,9 +2,9 @@ package Test::Stream::Workflow::Unit;
 use strict;
 use warnings;
 
-use Test::Stream::Sync;
+use Test::Stream::Sync();
 use Test::Stream::Context();
-use Test::Stream::DebugInfo;
+use Test::Stream::DebugInfo();
 
 use Carp qw/confess/;
 use Scalar::Util qw/reftype/;
@@ -199,6 +199,13 @@ but you have been warned that it may change in backwords incompatible ways.
 This message will be removed from this modules POD once it is considered
 stable.
 
+=head1 DEPRECATED
+
+B<This distribution is deprecated> in favor of L<Test2>, L<Test2::Suite>, and
+L<Test2::Workflow>.
+
+See L<Test::Stream::Manual::ToTest2> for a conversion guide.
+
 =head1 DESCRIPTION
 
 This package is a single unit of work to be done in a workflow. The unit may
@@ -336,6 +343,6 @@ Copyright 2015 Chad Granum E<lt>exodist7@gmail.comE<gt>.
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
-See F<http://www.perl.com/perl/misc/Artistic.html>
+See F<http://dev.perl.org/licenses/>
 
 =cut
